@@ -83,7 +83,7 @@ def runBlast(args):
         os.symlink(fileInGenome, fileInBlast)
 
 def main():
-    version = '0.0.3'
+    version = '0.0.4'
     parser = argparse.ArgumentParser(description='You are running fdog.addTaxon version ' + str(version) + '.')
     required = parser.add_argument_group('required arguments')
     optional = parser.add_argument_group('optional arguments')
@@ -153,10 +153,13 @@ def main():
             seq = str(inSeq[id].seq)
             # check ID
             id = re.sub('\|', '_', id)
-            if len(id) > 80:
-                # modIdIndex = modIdIndex + 1
-                # id = specName + "_" + str(modIdIndex)
+            oriId = id
+            if len(id) > 30:
+                modIdIndex = modIdIndex + 1
+                id = specName + "_" + str(modIdIndex)
                 longId = 'yes'
+                with open(specFile + '.mapping', 'a') as mappingFile:
+                    mappingFile.write('%s\t%s\n' % (id, oriId))
             if not id in tmpDict:
                 tmpDict[id] = 1
             else:
@@ -185,7 +188,9 @@ def main():
         cf.close()
         # warning about long header
         if longId == 'yes':
-            print('\033[91mWARNING: Headers are longer than 80 characters. It could cause some troubles!\033[0m')
+            print('\033[91mWARNING: Some headers longer than 80 characters have been automatically shortened. PLease check the %s.mapping file for details!\033[0m' % specFile)
+        else:
+            os.remove(specFile + '.mapping')
     else:
         print(genomePath + '/' + specName + '.fa already exists!')
 
